#!@PERL@

# --8<--8<--8<--8<--
#
# Copyright (C) 2010 Smithsonian Astrophysical Observatory
#
# This file is part of make-world
#
# make-world is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# make-world is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the
#       Free Software Foundation, Inc.
#       51 Franklin Street, Fifth Floor
#       Boston, MA  02110-1301, USA
#
# -->8-->8-->8-->8--


use strict;
use warnings;

package MakeWorld::Package::PerlModuleBuild;

use base 'MakeWorld::Package';
use Carp;

use File::Spec::Functions qw/ catdir curdir catfile /;

use MakeWorld::Global;
use MakeWorld::Run;

sub matches_contents { -f 'Build.PL'; }


sub configure
{
    my $self = shift;

    $self->SUPER::configure && return;

    # check for configure file. if its a dryrun, it's probable that the
    # source hasn't been unarchived and we won't see the configure file.
    # just assume its there. can't hurt!
    if ( -f 'Build.PL' || $opt{dryrun} )
    {
	my @args = ( '--install-base', $opt{prefix},
		     $self->{option}{configure}{arg} );

	run( qw[ perl Build.PL ], @args )
	  or die( "error configuring package\n" );
    }
}

sub build
{
    my $self = shift;

    $self->SUPER::build && return;

    run( catfile( curdir, 'Build'), 'build', $self->{option}{build}{arg} )
	or die( "error building package\n" );
}

sub test
{
    my $self = shift;

    $self->SUPER::test && return;

    run( catfile( curdir, 'Build'),  'test' )
      or die( "error testing package\n" );
}


sub install
{
    my $self = shift;

    $self->SUPER::install && return;

    run( catfile( curdir, 'Build'), 'install' )
      or die( "error installing package\n" );
}

1;
