#!perl

use strict;
use warnings;


use Test::More tests => 106;
use MakeWorld::Stages;

################################################################################
# Test default stages

my $default_stages = [ qw[ configure build test install ] ];


test_stages( $default_stages, [ qw[ build test ] ], [] );
test_stages( $default_stages, [], [ qw[ build test ] ] );

sub test_stages {

    my ( $default, $run, $dont ) = @_;

    my $stages = MakeWorld::Stages->new( );

    my %allowed = map { $_ => 1 } ( @$run ? @$run : @$default );
    delete @allowed{@$dont};

    my @allowed = keys %allowed;
    my @disallowed = grep { ! exists $allowed{$_} } @$default;

    for my $stage ( @$default )
    {
	ok( $stages->is_stage( $stage ), "is_stage: $stage" );
	ok( $stages->ok_to_run( $_ ), "ok_to_run: $_" )
	    for $stage, "$stage:pre", "$stage:main", "$stage:post";

	ok( $stages->is_legal_hook( $_), "hook: $_" )
	    for "$stage:pre", "$stage:post";

    }

    is( $stages->last_stage, $default->[-1], 'last stage' );

    # set up allowed stages
    $stages->allow_stages( $run, $dont );

    # all hooks are still legal
    for my $stage ( @$default )
    {
	ok( $stages->is_legal_hook( $_), "hook: $_" )
	    for "$stage:pre", "$stage:post";
    }

    for my $stage ( @allowed )
    {
	ok(  $stages->ok_to_run( $_ ), "ok_to_run: $_" )
	for $stage, "$stage:pre", "$stage:main", "$stage:post";
    }

    for my $stage ( @disallowed )
    {
	ok( ! $stages->ok_to_run( $_ ), "not ok_to_run: $_" )
	for $stage, "$stage:pre", "$stage:main", "$stage:post";
    }

}
